@@ -1,9 +1,12 @@
 #!/usr/bin/env python
 
-from __future__ import absolute_import, division, print_function, unicode_literals
 
 import unittest
 
+from stone.backend import (
+    remove_aliases_from_api,
+    CodeBackend
+)
 from stone.ir import (
     Alias,
     Api,
@@ -20,23 +23,12 @@ from stone.ir import (
     resolve_aliases,
     strip_alias
 )
-from stone.backend import (
-    remove_aliases_from_api,
-    CodeBackend
-)
 
 _MYPY = False
 if _MYPY:
     import typing  # noqa: F401 # pylint: disable=import-error,unused-import,useless-suppression
 
-# Hack to get around some of Python 2's standard library modules that
-# accept ascii-encodable unicode literals in lieu of strs, but where
-# actually passing such literals results in errors with mypy --py2. See
-# <https://github.com/python/typeshed/issues/756> and
-# <https://github.com/python/mypy/issues/2536>.
-import importlib
-argparse = importlib.import_module(str('argparse'))  # type: typing.Any
-
+import argparse
 class _Tester(CodeBackend):
     """A no-op backend used to test helper methods."""
     def generate(self, api):
